@@ -29,13 +29,14 @@
 
 #include "logger.h"
 
-#include "recordable.h"
-#include "peerrecorder.h"
-#include "connectivity/ip_utils.h"
 #include "conference.h"
-#include "media_codec.h"
+#include "media/recordable.h"
+#include "media/peerrecorder.h"
+#include "media/media_codec.h"
 #include "media/media_attribute.h"
 
+#include <dhtnet/ip_utils.h>
+
 #include <atomic>
 #include <mutex>
 #include <map>
@@ -59,7 +60,6 @@ namespace jami {
 
 class VoIPLink;
 class Account;
-struct AccountVideoCodecInfo;
 class AudioDeviceGuard;
 
 class Call;
@@ -371,6 +371,8 @@ public:
 
     virtual std::vector<MediaAttribute> getMediaAttributeList() const = 0;
 
+    virtual std::map<std::string, bool> getAudioStreams() const = 0;
+
 #ifdef ENABLE_VIDEO
     virtual void createSinks(ConfInfo& infos) = 0;
 #endif
@@ -415,11 +417,11 @@ public:
 
     void onTextMessage(std::map<std::string, std::string>&& messages);
 
-    virtual std::shared_ptr<AccountCodecInfo> getAudioCodec() const
+    virtual std::shared_ptr<SystemCodecInfo> getAudioCodec() const
     {
         return {};
     }
-    virtual std::shared_ptr<AccountCodecInfo> getVideoCodec() const
+    virtual std::shared_ptr<SystemCodecInfo> getVideoCodec() const
     {
         return {};
     }
