@@ -158,12 +158,6 @@ public:
             throw std::logic_error("Couldn't clone repository");
         }
         init();
-        // To get current active calls from previous commit, we need to read the history
-        auto convCommits = loadMessages({});
-        std::reverse(std::begin(convCommits), std::end(convCommits));
-        for (const auto& c : convCommits) {
-            updateActiveCalls(c);
-        }
     }
 
     void init()
@@ -176,22 +170,18 @@ public:
             accountId_ = shared->getAccountID();
             transferManager_ = std::make_shared<TransferManager>(shared->getAccountID(),
                                                                  repository_->id());
-            conversationDataPath_ = fileutils::get_data_dir() + DIR_SEPARATOR_STR
-                                    + shared->getAccountID() + DIR_SEPARATOR_STR
-                                    + "conversation_data" + DIR_SEPARATOR_STR + repository_->id();
-            fetchedPath_ = conversationDataPath_ + DIR_SEPARATOR_STR + "fetched";
-            sendingPath_ = conversationDataPath_ + DIR_SEPARATOR_STR + "sending";
-            lastDisplayedPath_ = conversationDataPath_ + DIR_SEPARATOR_STR
-                                 + ConversationMapKeys::LAST_DISPLAYED;
-            preferencesPath_ = conversationDataPath_ + DIR_SEPARATOR_STR
-                               + ConversationMapKeys::PREFERENCES;
-            activeCallsPath_ = conversationDataPath_ + DIR_SEPARATOR_STR
-                               + ConversationMapKeys::ACTIVE_CALLS;
-            hostedCallsPath_ = conversationDataPath_ + DIR_SEPARATOR_STR
-                               + ConversationMapKeys::HOSTED_CALLS;
+            conversationDataPath_ = fileutils::get_data_dir() / shared->getAccountID()
+                                        / "conversation_data" / repository_->id();
+            fetchedPath_ = conversationDataPath_ / "fetched";
+            sendingPath_ = conversationDataPath_ / "sending";
+            lastDisplayedPath_ = conversationDataPath_ / ConversationMapKeys::LAST_DISPLAYED;
+            preferencesPath_ = conversationDataPath_ / ConversationMapKeys::PREFERENCES;
+            activeCallsPath_ = conversationDataPath_ / ConversationMapKeys::ACTIVE_CALLS;
+            hostedCallsPath_ = conversationDataPath_ / ConversationMapKeys::HOSTED_CALLS;
             loadFetched();
             loadSending();
             loadLastDisplayed();
+            loadActiveCalls();
         }
     }
 
@@ -216,13 +206,6 @@ public:
     }
     mutable std::string fmtStr_;
 
-    /**
-     * If, for whatever reason, the daemon is stopped while hosting a conference,
-     * we need to announce the end of this call when restarting.
-     * To avoid to keep active calls forever.
-     */
-    std::vector<std::string> announceEndedCalls();
-
     ~Impl()
     {
         try {
@@ -233,9 +216,14 @@ public:
         }
     }
 
-    std::vector<std::string> refreshActiveCalls();
+    /**
+     * If, for whatever reason, the daemon is stopped while hosting a conference,
+     * we need to announce the end of this call when restarting.
+     * To avoid to keep active calls forever.
+     */
+    std::vector<std::string> commitsEndedCalls();
     bool isAdmin() const;
-    std::string repoPath() const;
+    std::filesystem::path repoPath() const;
 
     void announce(const std::string& commitId) const
     {
@@ -445,8 +433,8 @@ public:
                 }
             }
 
-            if (announceMember) {
-                shared->saveMembers(convId, repository_->memberUris("", {}));
+            if (announceMember && onMembersChanged_) {
+                onMembersChanged_(repository_->memberUris("", {}));
             }
         }
     }
@@ -536,7 +524,7 @@ public:
             auto file = fileutils::loadFile(hostedCallsPath_);
             // load values
             msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
-            std::lock_guard<std::mutex> lk {hostedCallsMtx_};
+            std::lock_guard<std::mutex> lk {activeCallsMtx_};
             oh.get().convert(hostedCalls_);
         } catch (const std::exception& e) {
             return;
@@ -557,28 +545,29 @@ public:
 
     std::string_view bannedType(const std::string& uri) const
     {
-        auto bannedMember = fmt::format("{}/banned/members/{}.crt", repoPath(), uri);
-        if (fileutils::isFile(bannedMember))
+        auto crt = fmt::format("{}.crt", uri);
+        auto bannedMember = repoPath() / "banned" / "members" / crt;
+        if (std::filesystem::is_regular_file(bannedMember))
             return "members"sv;
-        auto bannedAdmin = fmt::format("{}/banned/admins/{}.crt", repoPath(), uri);
-        if (fileutils::isFile(bannedAdmin))
+        auto bannedAdmin = repoPath() / "banned" / "admins" / crt;
+        if (std::filesystem::is_regular_file(bannedAdmin))
             return "admins"sv;
-        auto bannedInvited = fmt::format("{}/banned/invited/{}", repoPath(), uri);
-        if (fileutils::isFile(bannedInvited))
+        auto bannedInvited = repoPath() / "banned" / "invited" / uri;
+        if (std::filesystem::is_regular_file(bannedInvited))
             return "invited"sv;
-        auto bannedDevice = fmt::format("{}/banned/devices/{}.crt", repoPath(), uri);
-        if (fileutils::isFile(bannedDevice))
+        auto bannedDevice = repoPath() / "banned" / "devices" / crt;
+        if (std::filesystem::is_regular_file(bannedDevice))
             return "devices"sv;
         return {};
     }
 
-    std::shared_ptr<ChannelSocket> gitSocket(const DeviceId& deviceId) const
+    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(const DeviceId& deviceId) const
     {
         auto deviceSockets = gitSocketList_.find(deviceId);
         return (deviceSockets != gitSocketList_.end()) ? deviceSockets->second : nullptr;
     }
 
-    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket)
+    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<dhtnet::ChannelSocket>& socket)
     {
         gitSocketList_[deviceId] = socket;
     }
@@ -612,27 +601,28 @@ public:
     std::set<std::string> fetchingRemotes_ {}; // store current remote in fetch
     std::deque<std::tuple<std::string, std::string, OnPullCb>> pullcbs_ {};
     std::shared_ptr<TransferManager> transferManager_ {};
-    std::string conversationDataPath_ {};
-    std::string fetchedPath_ {};
+    std::filesystem::path conversationDataPath_ {};
+    std::filesystem::path fetchedPath_ {};
+
     std::mutex fetchedDevicesMtx_ {};
     std::set<std::string> fetchedDevices_ {};
     // Manage last message displayed and status
-    std::string sendingPath_ {};
+    std::filesystem::path sendingPath_ {};
     std::vector<std::string> sending_ {};
     // Manage last message displayed
     std::string accountId_ {};
-    std::string lastDisplayedPath_ {};
-    std::string preferencesPath_ {};
+    std::filesystem::path lastDisplayedPath_ {};
+    std::filesystem::path preferencesPath_ {};
     mutable std::mutex lastDisplayedMtx_ {}; // for lastDisplayed_
     mutable std::map<std::string, std::string> lastDisplayed_ {};
     std::function<void(const std::string&, const std::string&)> lastDisplayedUpdatedCb_ {};
+    OnMembersChanged onMembersChanged_ {};
 
     // Manage hosted calls on this device
-    std::string hostedCallsPath_ {};
-    mutable std::mutex hostedCallsMtx_ {};
+    std::filesystem::path hostedCallsPath_ {};
     mutable std::map<std::string, uint64_t /* start time */> hostedCalls_ {};
     // Manage active calls for this conversation (can be hosted by other devices)
-    std::string activeCallsPath_ {};
+    std::filesystem::path activeCallsPath_ {};
     mutable std::mutex activeCallsMtx_ {};
     mutable std::vector<std::map<std::string, std::string>> activeCalls_ {};
 
@@ -652,12 +642,12 @@ Conversation::Impl::isAdmin() const
     if (!shared)
         return false;
 
-    auto adminsPath = repoPath() + DIR_SEPARATOR_STR + "admins";
+    auto adminsPath = repoPath() / "admins";
     auto cert = shared->identity().second;
     if (!cert->issuer)
         return false;
     auto uri = cert->issuer->getId().toString();
-    return fileutils::isFile(fileutils::getFullPath(adminsPath, uri + ".crt"));
+    return std::filesystem::is_regular_file(fileutils::getFullPath(adminsPath, uri + ".crt"));
 }
 
 std::vector<std::map<std::string, std::string>>
@@ -687,15 +677,7 @@ Conversation::Impl::getMembers(bool includeInvited, bool includeLeft, bool inclu
 }
 
 std::vector<std::string>
-Conversation::Impl::refreshActiveCalls()
-{
-    loadActiveCalls();
-    loadHostedCalls();
-    return announceEndedCalls();
-}
-
-std::vector<std::string>
-Conversation::Impl::announceEndedCalls()
+Conversation::Impl::commitsEndedCalls()
 {
     auto shared = account_.lock();
     // Handle current calls
@@ -733,19 +715,13 @@ Conversation::Impl::announceEndedCalls()
     hostedCalls_.clear();
     saveActiveCalls();
     saveHostedCalls();
-    lkA.unlock();
-    lk.unlock();
-    if (!commits.empty()) {
-        announce(commits);
-    }
     return commits;
 }
 
-std::string
+std::filesystem::path
 Conversation::Impl::repoPath() const
 {
-    return fileutils::get_data_dir() + DIR_SEPARATOR_STR + accountId_ + DIR_SEPARATOR_STR
-           + "conversations" + DIR_SEPARATOR_STR + repository_->id();
+    return fileutils::get_data_dir() / accountId_ / "conversations" / repository_->id();
 }
 
 std::vector<std::map<std::string, std::string>>
@@ -841,14 +817,14 @@ Conversation::addMember(const std::string& contactUri, const OnDoneCb& cb)
     });
 }
 
-std::shared_ptr<ChannelSocket>
+std::shared_ptr<dhtnet::ChannelSocket>
 Conversation::gitSocket(const DeviceId& deviceId) const
 {
     return pimpl_->gitSocket(deviceId);
 }
 
 void
-Conversation::addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket)
+Conversation::addGitSocket(const DeviceId& deviceId, const std::shared_ptr<dhtnet::ChannelSocket>& socket)
 {
     pimpl_->addGitSocket(deviceId, socket);
 }
@@ -876,6 +852,12 @@ Conversation::connectivityChanged()
         pimpl_->swarmManager_->maintainBuckets();
 }
 
+std::vector<jami::DeviceId>
+Conversation::getDeviceIdList() const
+{
+    return pimpl_->swarmManager_->getRoutingTable().getAllNodes();
+}
+
 bool
 Conversation::hasSwarmChannel(const std::string& deviceId)
 {
@@ -1063,14 +1045,14 @@ bool
 Conversation::isMember(const std::string& uri, bool includeInvited) const
 {
     auto repoPath = pimpl_->repoPath();
-    auto invitedPath = repoPath + DIR_SEPARATOR_STR "invited";
-    auto adminsPath = repoPath + DIR_SEPARATOR_STR "admins";
-    auto membersPath = repoPath + DIR_SEPARATOR_STR "members";
-    std::vector<std::string> pathsToCheck = {adminsPath, membersPath};
+    auto invitedPath = repoPath / "invited";
+    auto adminsPath = repoPath / "admins";
+    auto membersPath = repoPath / "members";
+    std::vector<std::filesystem::path> pathsToCheck = {adminsPath, membersPath};
     if (includeInvited)
         pathsToCheck.emplace_back(invitedPath);
     for (const auto& path : pathsToCheck) {
-        for (const auto& certificate : fileutils::readDirectory(path)) {
+        for (const auto& certificate : dhtnet::fileutils::readDirectory(path)) {
             std::string_view crtUri = certificate;
             auto crtIt = crtUri.find(".crt");
             if (path != invitedPath && crtIt == std::string_view::npos) {
@@ -1369,19 +1351,21 @@ Conversation::sync(const std::string& member,
 {
     JAMI_INFO() << "Sync " << id() << " with " << deviceId;
     pull(deviceId, std::move(cb), commitId);
-    if (auto account = pimpl_->account_.lock()) {
-        // For waiting request, downloadFile
-        for (const auto& wr : dataTransfer()->waitingRequests()) {
-            auto path = fileutils::get_data_dir() + DIR_SEPARATOR_STR + account->getAccountID()
-                        + DIR_SEPARATOR_STR + "conversation_data" + DIR_SEPARATOR_STR + id()
-                        + DIR_SEPARATOR_STR + wr.fileId;
-            auto start = fileutils::size(path);
-            if (start < 0)
-                start = 0;
-            downloadFile(wr.interactionId, wr.fileId, wr.path, member, deviceId, start);
+    dht::ThreadPool::io().run([member, deviceId, a = pimpl_->account_, w=weak_from_this()]{
+        auto sthis = w.lock();
+        if (auto account = a.lock()) {
+            // For waiting request, downloadFile
+            for (const auto& wr : sthis->dataTransfer()->waitingRequests()) {
+                auto path = fileutils::get_data_dir() / account->getAccountID()
+                            / "conversation_data" / sthis->id() / wr.fileId;
+                auto start = fileutils::size(path.string());
+                if (start < 0)
+                    start = 0;
+                sthis->downloadFile(wr.interactionId, wr.fileId, wr.path, member, deviceId, start);
+            }
+            account->sendProfile(sthis->id(), member, deviceId);
         }
-        account->sendProfile(id(), member, deviceId);
-    }
+    });
 }
 
 std::map<std::string, std::string>
@@ -1421,7 +1405,7 @@ void
 Conversation::erase()
 {
     if (pimpl_->conversationDataPath_ != "")
-        fileutils::removeAll(pimpl_->conversationDataPath_, true);
+        dhtnet::fileutils::removeAll(pimpl_->conversationDataPath_, true);
     if (!pimpl_->repository_)
         return;
     std::lock_guard<std::mutex> lk(pimpl_->writeMtx_);
@@ -1475,11 +1459,11 @@ Conversation::infos() const
 void
 Conversation::updatePreferences(const std::map<std::string, std::string>& map)
 {
-    auto filePath = fmt::format("{}/preferences", pimpl_->conversationDataPath_);
+    auto filePath = pimpl_->conversationDataPath_ / "preferences";
     auto prefs = map;
     auto itLast = prefs.find(LAST_MODIFIED);
     if (itLast != prefs.end()) {
-        if (fileutils::isFile(filePath)) {
+        if (std::filesystem::is_regular_file(filePath)) {
             auto lastModified = fileutils::lastWriteTimeInSeconds(filePath);
             try {
                 if (lastModified >= std::stoul(itLast->second))
@@ -1503,7 +1487,7 @@ Conversation::preferences(bool includeLastModified) const
 {
     try {
         std::map<std::string, std::string> preferences;
-        auto filePath = fmt::format("{}/preferences", pimpl_->conversationDataPath_);
+        auto filePath = pimpl_->conversationDataPath_ / "preferences";
         auto file = fileutils::loadFile(filePath);
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(preferences);
@@ -1520,7 +1504,7 @@ std::vector<uint8_t>
 Conversation::vCard() const
 {
     try {
-        return fileutils::loadFile(pimpl_->repoPath() + DIR_SEPARATOR_STR + "profile.vcf");
+        return fileutils::loadFile(pimpl_->repoPath() / "profile.vcf");
     } catch (...) {
     }
     return {};
@@ -1553,12 +1537,12 @@ Conversation::onFileChannelRequest(const std::string& member,
 
     auto path = dataTransfer()->path(fileId);
 
-    if (!fileutils::isFile(path)) {
+    if (!std::filesystem::is_regular_file(path)) {
         // Check if dangling symlink
-        if (fileutils::isSymLink(path)) {
-            fileutils::remove(path, true);
+        if (std::filesystem::is_symlink(path)) {
+            dhtnet::fileutils::remove(path, true);
         }
-        JAMI_DEBUG("[Account {:s}] {:s} asked for non existing file {:s} in {:s}",
+        JAMI_DEBUG("[Account {:s}] {:s} asked for non existing file {} in {:s}",
                    pimpl_->accountId_,
                    member,
                    fileId,
@@ -1588,19 +1572,30 @@ Conversation::downloadFile(const std::string& interactionId,
                            std::size_t end)
 {
     auto commit = getCommit(interactionId);
-    if (commit == std::nullopt || commit->find("type") == commit->end()
-        || commit->find("sha3sum") == commit->end() || commit->find("tid") == commit->end()
-        || commit->at("type") != "application/data-transfer+json") {
-        JAMI_ERR() << "Cannot download file without linked interaction " << fileId;
+    if (commit == std::nullopt || commit->at("type") != "application/data-transfer+json") {
+        JAMI_ERROR("Commit doesn't exists or is not a file transfer");
+        return false;
+    }
+    auto tid = commit->find("tid");
+    auto sha3sum = commit->find("sha3sum");
+    auto size_str = commit->find("totalSize");
+
+    if (tid == commit->end() || sha3sum == commit->end() || size_str == commit->end()) {
+        JAMI_ERROR("Invalid file transfer commit (missing tid, size or sha3)");
+        return false;
+    }
+
+    auto totalSize = to_int<ssize_t>(size_str->second, (ssize_t)-1);
+    if (totalSize < 0) {
+        JAMI_ERROR("Invalid file size {}", totalSize);
         return false;
     }
-    auto sha3sum = commit->at("sha3sum");
-    auto size_str = commit->at("totalSize");
-    auto totalSize = to_int<size_t>(size_str);
 
     // Be sure to not lock conversation
     dht::ThreadPool().io().run(
-        [w = weak(), deviceId, fileId, interactionId, sha3sum, path, totalSize, start, end] {
+        [w = weak(),
+         deviceId,
+         fileId, interactionId, sha3sum=sha3sum->second, path, totalSize, start, end] {
             if (auto shared = w.lock()) {
                 auto acc = shared->pimpl_->account_.lock();
                 if (!acc)
@@ -1686,13 +1681,11 @@ Conversation::setMessageDisplayed(const std::string& uri, const std::string& int
 void
 Conversation::updateLastDisplayed(const std::map<std::string, std::string>& map)
 {
-    auto filePath = fmt::format("{}/{}",
-                                pimpl_->conversationDataPath_,
-                                ConversationMapKeys::LAST_DISPLAYED);
+    auto filePath = pimpl_->conversationDataPath_ / ConversationMapKeys::LAST_DISPLAYED;
     auto prefs = map;
     auto itLast = prefs.find(LAST_MODIFIED);
     if (itLast != prefs.end()) {
-        if (fileutils::isFile(filePath)) {
+        if (std::filesystem::is_regular_file(filePath)) {
             auto lastModified = fileutils::lastWriteTimeInSeconds(filePath);
             try {
                 if (lastModified >= std::stoul(itLast->second))
@@ -1763,9 +1756,7 @@ Conversation::displayed() const
 {
     try {
         std::map<std::string, std::string> lastDisplayed;
-        auto filePath = fmt::format("{}/{}",
-                                    pimpl_->conversationDataPath_,
-                                    ConversationMapKeys::LAST_DISPLAYED);
+        auto filePath = pimpl_->conversationDataPath_/ ConversationMapKeys::LAST_DISPLAYED;
         auto file = fileutils::loadFile(filePath);
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(lastDisplayed);
@@ -1915,9 +1906,19 @@ Conversation::bootstrap(std::function<void()> onBootstraped, const std::vector<D
 }
 
 std::vector<std::string>
-Conversation::refreshActiveCalls()
+Conversation::commitsEndedCalls()
 {
-    return pimpl_->refreshActiveCalls();
+    pimpl_->loadActiveCalls();
+    pimpl_->loadHostedCalls();
+    auto commits = pimpl_->commitsEndedCalls();
+    if (!commits.empty()) {
+        // Announce to client
+        dht::ThreadPool::io().run([w = weak(), commits]{
+            if (auto sthis = w.lock())
+                sthis->pimpl_->announce(commits);
+        });
+    }
+    return commits;
 }
 
 void
@@ -1927,6 +1928,12 @@ Conversation::onLastDisplayedUpdated(
     pimpl_->lastDisplayedUpdatedCb_ = std::move(lastDisplayedUpdatedCb);
 }
 
+void
+Conversation::onMembersChanged(OnMembersChanged&& cb)
+{
+    pimpl_->onMembersChanged_ = std::move(cb);
+}
+
 void
 Conversation::onNeedSocket(NeedSocketCb needSocket)
 {
@@ -1936,7 +1943,7 @@ Conversation::onNeedSocket(NeedSocketCb needSocket)
     };
 }
 void
-Conversation::addSwarmChannel(std::shared_ptr<ChannelSocket> channel)
+Conversation::addSwarmChannel(std::shared_ptr<dhtnet::ChannelSocket> channel)
 {
     pimpl_->swarmManager_->addChannel(std::move(channel));
 }
@@ -1997,7 +2004,7 @@ Conversation::hostConference(Json::Value&& message, OnDoneCb&& cb)
     auto now = std::chrono::system_clock::now();
     auto nowSecs = std::chrono::duration_cast<std::chrono::seconds>(now.time_since_epoch()).count();
     {
-        std::lock_guard<std::mutex> lk(pimpl_->hostedCallsMtx_);
+        std::lock_guard<std::mutex> lk(pimpl_->activeCallsMtx_);
         pimpl_->hostedCalls_[message["confId"].asString()] = nowSecs;
         pimpl_->saveHostedCalls();
     }
@@ -2014,7 +2021,7 @@ Conversation::isHosting(const std::string& confId) const
     auto info = infos();
     if (info["rdvDevice"] == shared->currentDeviceId() && info["rdvHost"] == shared->getUsername())
         return true; // We are the current device Host
-    std::lock_guard<std::mutex> lk(pimpl_->hostedCallsMtx_);
+    std::lock_guard<std::mutex> lk(pimpl_->activeCallsMtx_);
     return pimpl_->hostedCalls_.find(confId) != pimpl_->hostedCalls_.end();
 }
 
@@ -2028,7 +2035,7 @@ Conversation::removeActiveConference(Json::Value&& message, OnDoneCb&& cb)
 
     auto erased = false;
     {
-        std::lock_guard<std::mutex> lk(pimpl_->hostedCallsMtx_);
+        std::lock_guard<std::mutex> lk(pimpl_->activeCallsMtx_);
         erased = pimpl_->hostedCalls_.erase(message["confId"].asString());
     }
     if (erased) {
@@ -2044,5 +2051,4 @@ Conversation::currentCalls() const
     std::lock_guard<std::mutex> lk(pimpl_->activeCallsMtx_);
     return pimpl_->activeCalls_;
 }
-
 } // namespace jami
