@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2022 Savoir-faire Linux Inc.
+ *  Copyright (C) 2014-2023 Savoir-faire Linux Inc.
  *  Authors: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *           Simon Désaulniers <simon.desaulniers@savoirfairelinux.com>
  *           Sébastien Blin <sebastien.blin@savoirfairelinux.com>
@@ -67,15 +67,15 @@ public:
      */
     Dht(std::unique_ptr<net::DatagramSocket>&& sock, const Config& config, const Sp<Logger>& l = {});
 
-    Dht(std::unique_ptr<net::DatagramSocket>&& sock, const Config& config, const Logger& l = {})
-        : Dht(std::move(sock), config, std::make_shared<Logger>(l)) {}
-
     virtual ~Dht();
 
     /**
      * Get the ID of the node.
      */
     inline const InfoHash& getNodeId() const override { return myid; }
+    void setOnPublicAddressChanged(PublicAddressChangedCb cb) override {
+        publicAddressChangedCb_ = std::move(cb);
+    }
 
     NodeStatus updateStatus(sa_family_t af) override;
 
@@ -265,7 +265,6 @@ public:
      */
     void connectivityChanged(sa_family_t) override;
     void connectivityChanged() override {
-        reported_addr.clear();
         connectivityChanged(AF_INET);
         connectivityChanged(AF_INET6);
     }
@@ -384,11 +383,14 @@ private:
     TypeStore types;
 
     using SearchMap = std::map<InfoHash, Sp<Search>>;
+    using ReportedAddr = std::pair<unsigned, SockAddr>;
+
     struct Kad {
         RoutingTable buckets {};
         SearchMap searches {};
         unsigned pending_pings {0};
         NodeStatus status;
+        std::vector<ReportedAddr> reported_addr;
 
         NodeStatus getStatus(time_point now) const;
         NodeStats getNodesStats(time_point now, const InfoHash& myid) const;
@@ -396,6 +398,7 @@ private:
 
     Kad dht4 {};
     Kad dht6 {};
+    PublicAddressChangedCb publicAddressChangedCb_ {};
 
     std::vector<std::pair<std::string,std::string>> bootstrap_nodes {};
     std::chrono::steady_clock::duration bootstrap_period {BOOTSTRAP_PERIOD};
@@ -423,8 +426,6 @@ private:
     Sp<Scheduler::Job> nextStorageMaintenance {};
 
     net::NetworkEngine network_engine;
-    using ReportedAddr = std::pair<unsigned, SockAddr>;
-    std::vector<ReportedAddr> reported_addr;
 
     std::string persistPath;
 
@@ -567,7 +568,7 @@ private:
      * @param sr  The search for which we want to announce a value.
      * @param announce  The 'announce' structure.
      */
-    void searchSendAnnounceValue(const Sp<Search>& sr);
+    void searchSendAnnounceValue(const Sp<Search>& sr, unsigned syncLevel = TARGET_NODES);
 
     /**
      * Main process of a Search's operations. This function will demand the
