@@ -36,7 +36,7 @@
 #include <assert.h>
 
 static int
-compute_psk_from_ticket(const tls13_ticket_st *ticket, gnutls_datum_t *key)
+compute_psk_from_ticket(const tls13_ticket_st * ticket, gnutls_datum_t * key)
 {
 	int ret;
 
@@ -51,10 +51,10 @@ compute_psk_from_ticket(const tls13_ticket_st *ticket, gnutls_datum_t *key)
 	key->size = ticket->prf->output_size;
 
 	ret = _tls13_expand_secret2(ticket->prf,
-				    RESUMPTION_LABEL, sizeof(RESUMPTION_LABEL)-1,
-				    ticket->nonce, ticket->nonce_size,
-				    ticket->resumption_master_secret,
-				    key->size,
+				    RESUMPTION_LABEL,
+				    sizeof(RESUMPTION_LABEL) - 1, ticket->nonce,
+				    ticket->nonce_size,
+				    ticket->resumption_master_secret, key->size,
 				    key->data);
 	if (ret < 0)
 		gnutls_assert();
@@ -63,10 +63,8 @@ compute_psk_from_ticket(const tls13_ticket_st *ticket, gnutls_datum_t *key)
 }
 
 static int
-compute_binder_key(const mac_entry_st *prf,
-		   const uint8_t *key, size_t keylen,
-		   bool resuming,
-		   void *out)
+compute_binder_key(const mac_entry_st * prf,
+		   const uint8_t * key, size_t keylen, bool resuming, void *out)
 {
 	int ret;
 	const char ext_label[] = EXT_BINDER_LABEL;
@@ -93,10 +91,11 @@ compute_binder_key(const mac_entry_st *prf,
 
 static int
 compute_psk_binder(gnutls_session_t session,
-		   const mac_entry_st *prf, unsigned binders_length,
+		   const mac_entry_st * prf, unsigned binders_length,
 		   int exts_length, int ext_offset,
-		   const gnutls_datum_t *psk, const gnutls_datum_t *client_hello,
-		   bool resuming, void *out)
+		   const gnutls_datum_t * psk,
+		   const gnutls_datum_t * client_hello, bool resuming,
+		   void *out)
 {
 	int ret;
 	unsigned client_hello_pos, extensions_len_pos;
@@ -108,8 +107,11 @@ compute_psk_binder(gnutls_session_t session,
 	if (session->security_parameters.entity == GNUTLS_CLIENT) {
 		if (session->internals.hsk_flags & HSK_HRR_RECEIVED) {
 			ret = gnutls_buffer_append_data(&handshake_buf,
-							(const void *) session->internals.handshake_hash_buffer.data,
-							session->internals.handshake_hash_buffer.length);
+							(const void *)
+							session->
+							internals.handshake_hash_buffer.data,
+							session->
+							internals.handshake_hash_buffer.length);
 			if (ret < 0) {
 				gnutls_assert();
 				goto error;
@@ -117,36 +119,52 @@ compute_psk_binder(gnutls_session_t session,
 		}
 
 		client_hello_pos = handshake_buf.length;
-		ret = gnutls_buffer_append_data(&handshake_buf, client_hello->data,
-						client_hello->size);
+		ret =
+		    gnutls_buffer_append_data(&handshake_buf,
+					      client_hello->data,
+					      client_hello->size);
 		if (ret < 0) {
 			gnutls_assert();
 			goto error;
 		}
 
 		/* This is a ClientHello message */
-		handshake_buf.data[client_hello_pos] = GNUTLS_HANDSHAKE_CLIENT_HELLO;
+		handshake_buf.data[client_hello_pos] =
+		    GNUTLS_HANDSHAKE_CLIENT_HELLO;
 
 		/* At this point we have not yet added the binders to the ClientHello,
 		 * but we have to overwrite the size field, pretending as if binders
 		 * of the correct length were present.
 		 */
-		_gnutls_write_uint24(handshake_buf.length - client_hello_pos + binders_length - 2, &handshake_buf.data[client_hello_pos + 1]);
-		_gnutls_write_uint16(handshake_buf.length - client_hello_pos + binders_length - ext_offset,
-				     &handshake_buf.data[client_hello_pos + ext_offset]);
-		extensions_len_pos = handshake_buf.length - client_hello_pos - exts_length - 2;
+		_gnutls_write_uint24(handshake_buf.length - client_hello_pos +
+				     binders_length - 2,
+				     &handshake_buf.data[client_hello_pos + 1]);
+		_gnutls_write_uint16(handshake_buf.length - client_hello_pos +
+				     binders_length - ext_offset,
+				     &handshake_buf.data[client_hello_pos +
+							 ext_offset]);
+		extensions_len_pos =
+		    handshake_buf.length - client_hello_pos - exts_length - 2;
 		_gnutls_write_uint16(exts_length + binders_length + 2,
-				     &handshake_buf.data[client_hello_pos + extensions_len_pos]);
+				     &handshake_buf.data[client_hello_pos +
+							 extensions_len_pos]);
 	} else {
 		if (session->internals.hsk_flags & HSK_HRR_SENT) {
-			if (unlikely(session->internals.handshake_hash_buffer.length <= client_hello->size)) {
-				ret = gnutls_assert_val(GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER);
+			if (unlikely
+			    (session->internals.handshake_hash_buffer.length <=
+			     client_hello->size)) {
+				ret =
+				    gnutls_assert_val
+				    (GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER);
 				goto error;
 			}
 
 			ret = gnutls_buffer_append_data(&handshake_buf,
-							session->internals.handshake_hash_buffer.data,
-							session->internals.handshake_hash_buffer.length - client_hello->size);
+							session->
+							internals.handshake_hash_buffer.data,
+							session->
+							internals.handshake_hash_buffer.length
+							- client_hello->size);
 			if (ret < 0) {
 				gnutls_assert();
 				goto error;
@@ -154,13 +172,16 @@ compute_psk_binder(gnutls_session_t session,
 		}
 
 		if (unlikely(client_hello->size <= binders_length)) {
-			ret = gnutls_assert_val(GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER);
+			ret =
+			    gnutls_assert_val
+			    (GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER);
 			goto error;
 		}
 
-		ret = gnutls_buffer_append_data(&handshake_buf,
-						(const void *) client_hello->data,
-						client_hello->size - binders_length);
+		ret = gnutls_buffer_append_data(&handshake_buf, (const void *)
+						client_hello->data,
+						client_hello->size -
+						binders_length);
 		if (ret < 0) {
 			gnutls_assert();
 			goto error;
@@ -168,38 +189,37 @@ compute_psk_binder(gnutls_session_t session,
 	}
 
 	ret = compute_binder_key(prf,
-				 psk->data, psk->size, resuming,
-				 binder_key);
+				 psk->data, psk->size, resuming, binder_key);
 	if (ret < 0) {
 		gnutls_assert();
 		goto error;
 	}
 
-	ret = _gnutls13_compute_finished(prf, binder_key,
-					 &handshake_buf,
-					 out);
+	ret = _gnutls13_compute_finished(prf, binder_key, &handshake_buf, out);
 	if (ret < 0) {
 		gnutls_assert();
 		goto error;
 	}
 
 	ret = 0;
-error:
+ error:
 	_gnutls_buffer_clear(&handshake_buf);
 	return ret;
 }
 
 static int
-generate_early_secrets(gnutls_session_t session,
-		       const mac_entry_st *prf)
+generate_early_secrets(gnutls_session_t session, const mac_entry_st * prf)
 {
 	int ret;
 
-	ret = _tls13_derive_secret2(prf, EARLY_TRAFFIC_LABEL, sizeof(EARLY_TRAFFIC_LABEL)-1,
-				    session->internals.handshake_hash_buffer.data,
-				    session->internals.handshake_hash_buffer_client_hello_len,
-				    session->key.proto.tls13.temp_secret,
-				    session->key.proto.tls13.e_ckey);
+	ret =
+	    _tls13_derive_secret2(prf, EARLY_TRAFFIC_LABEL,
+				  sizeof(EARLY_TRAFFIC_LABEL) - 1,
+				  session->internals.handshake_hash_buffer.data,
+				  session->
+				  internals.handshake_hash_buffer_client_hello_len,
+				  session->key.proto.tls13.temp_secret,
+				  session->key.proto.tls13.e_ckey);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
@@ -209,11 +229,14 @@ generate_early_secrets(gnutls_session_t session,
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
-	ret = _tls13_derive_secret2(prf, EARLY_EXPORTER_MASTER_LABEL, sizeof(EARLY_EXPORTER_MASTER_LABEL)-1,
-				    session->internals.handshake_hash_buffer.data,
-				    session->internals.handshake_hash_buffer_client_hello_len,
-				    session->key.proto.tls13.temp_secret,
-				    session->key.proto.tls13.ap_expkey);
+	ret =
+	    _tls13_derive_secret2(prf, EARLY_EXPORTER_MASTER_LABEL,
+				  sizeof(EARLY_EXPORTER_MASTER_LABEL) - 1,
+				  session->internals.handshake_hash_buffer.data,
+				  session->
+				  internals.handshake_hash_buffer_client_hello_len,
+				  session->key.proto.tls13.temp_secret,
+				  session->key.proto.tls13.ap_expkey);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
@@ -228,8 +251,7 @@ generate_early_secrets(gnutls_session_t session,
 
 /* Calculate TLS 1.3 Early Secret and the derived secrets from the
  * selected PSK. */
-int
-_gnutls_generate_early_secrets_for_psk(gnutls_session_t session)
+int _gnutls_generate_early_secrets_for_psk(gnutls_session_t session)
 {
 	const uint8_t *psk;
 	size_t psk_size;
@@ -265,8 +287,8 @@ client_send_params(gnutls_session_t session,
 	int ret, ext_offset = 0;
 	uint8_t binder_value[MAX_HASH_SIZE];
 	size_t spos;
-	gnutls_datum_t username = {NULL, 0};
-	gnutls_datum_t user_key = {NULL, 0}, rkey = {NULL, 0};
+	gnutls_datum_t username = { NULL, 0 };
+	gnutls_datum_t user_key = { NULL, 0 }, rkey = { NULL, 0 };
 	unsigned client_hello_len;
 	unsigned next_idx;
 	const mac_entry_st *prf_res = NULL;
@@ -280,7 +302,7 @@ client_send_params(gnutls_session_t session,
 	tls13_ticket_st *ticket = &session->internals.tls13_ticket;
 
 	if (((session->internals.flags & GNUTLS_NO_TICKETS) ||
-	    session->internals.tls13_ticket.ticket.data == NULL) &&
+	     session->internals.tls13_ticket.ticket.data == NULL) &&
 	    (!cred || !_gnutls_have_psk_credentials(cred, session))) {
 
 		return 0;
@@ -332,14 +354,19 @@ client_send_params(gnutls_session_t session,
 		ob_ticket_age = ticket_age + ticket->age_add;
 
 		if ((ret = _gnutls_buffer_append_data_prefix(extdata, 16,
-							     ticket->ticket.data,
-							     ticket->ticket.size)) < 0) {
+							     ticket->
+							     ticket.data,
+							     ticket->
+							     ticket.size)) <
+		    0) {
 			gnutls_assert();
 			goto cleanup;
 		}
 
 		/* Now append the obfuscated ticket age */
-		if ((ret = _gnutls_buffer_append_prefix(extdata, 32, ob_ticket_age)) < 0) {
+		if ((ret =
+		     _gnutls_buffer_append_prefix(extdata, 32,
+						  ob_ticket_age)) < 0) {
 			gnutls_assert();
 			goto cleanup;
 		}
@@ -354,13 +381,17 @@ client_send_params(gnutls_session_t session,
 
 		if (cred->binder_algo == NULL) {
 			gnutls_assert();
-			ret = gnutls_assert_val(GNUTLS_E_INSUFFICIENT_CREDENTIALS);
+			ret =
+			    gnutls_assert_val
+			    (GNUTLS_E_INSUFFICIENT_CREDENTIALS);
 			goto cleanup;
 		}
 
 		prf_psk = cred->binder_algo;
 
-		ret = _gnutls_find_psk_key(session, cred, &username, &tkey, &free_username);
+		ret =
+		    _gnutls_find_psk_key(session, cred, &username, &tkey,
+					 &free_username);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -373,7 +404,8 @@ client_send_params(gnutls_session_t session,
 
 		if (!free_username) {
 			/* we need to copy the key */
-			ret = _gnutls_set_datum(&user_key, tkey.data, tkey.size);
+			ret =
+			    _gnutls_set_datum(&user_key, tkey.data, tkey.size);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
@@ -383,7 +415,9 @@ client_send_params(gnutls_session_t session,
 			user_key.size = tkey.size;
 		}
 
-		ret = _gnutls_auth_info_init(session, GNUTLS_CRD_PSK, sizeof(psk_auth_info_st), 1);
+		ret =
+		    _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
+					   sizeof(psk_auth_info_st), 1);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -392,11 +426,16 @@ client_send_params(gnutls_session_t session,
 		info = _gnutls_get_auth_info(session, GNUTLS_CRD_PSK);
 		assert(info != NULL);
 
-		_gnutls_copy_psk_username(info, &username);
+		ret = _gnutls_copy_psk_username(info, username);
+		if (ret < 0) {
+			gnutls_assert();
+			goto cleanup;
+		}
 
 		if ((ret = _gnutls_buffer_append_data_prefix(extdata, 16,
 							     username.data,
-							     username.size)) < 0) {
+							     username.size)) <
+		    0) {
 			gnutls_assert();
 			goto cleanup;
 		}
@@ -420,15 +459,15 @@ client_send_params(gnutls_session_t session,
 
 	_gnutls_write_uint16(psk_id_len, &extdata->data[spos]);
 
-	binders_pos = extdata->length-spos;
+	binders_pos = extdata->length - spos;
 	ext_offset = _gnutls_ext_get_extensions_offset(session);
 
 	/* Compute the binders. extdata->data points to the start
 	 * of this client hello. */
 	assert(extdata->length >= sizeof(mbuffer_st));
-	assert(ext_offset >= (ssize_t)sizeof(mbuffer_st));
+	assert(ext_offset >= (ssize_t) sizeof(mbuffer_st));
 	ext_offset -= sizeof(mbuffer_st);
-	client_hello_len = extdata->length-sizeof(mbuffer_st);
+	client_hello_len = extdata->length - sizeof(mbuffer_st);
 
 	next_idx = 0;
 
@@ -441,7 +480,7 @@ client_send_params(gnutls_session_t session,
 	if (prf_res && rkey.size > 0) {
 		gnutls_datum_t client_hello;
 
-		client_hello.data = extdata->data+sizeof(mbuffer_st);
+		client_hello.data = extdata->data + sizeof(mbuffer_st);
 		client_hello.size = client_hello_len;
 
 		ret = compute_psk_binder(session, prf_res,
@@ -463,12 +502,16 @@ client_send_params(gnutls_session_t session,
 		session->key.binders[next_idx].resumption = 1;
 		session->key.binders[next_idx].idx = next_idx;
 
-		_gnutls_handshake_log("EXT[%p]: sent PSK resumption identity (%d)\n", session, next_idx);
+		_gnutls_handshake_log
+		    ("EXT[%p]: sent PSK resumption identity (%d)\n", session,
+		     next_idx);
 
 		next_idx++;
 
 		/* Add the binder */
-		ret = _gnutls_buffer_append_data_prefix(extdata, 8, binder_value, prf_res->output_size);
+		ret =
+		    _gnutls_buffer_append_data_prefix(extdata, 8, binder_value,
+						      prf_res->output_size);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -480,13 +523,13 @@ client_send_params(gnutls_session_t session,
 	if (prf_psk && user_key.size > 0 && info) {
 		gnutls_datum_t client_hello;
 
-		client_hello.data = extdata->data+sizeof(mbuffer_st);
+		client_hello.data = extdata->data + sizeof(mbuffer_st);
 		client_hello.size = client_hello_len;
 
 		ret = compute_psk_binder(session, prf_psk,
 					 binders_len, binders_pos,
-					 ext_offset, &user_key, &client_hello, 0,
-					 binder_value);
+					 ext_offset, &user_key, &client_hello,
+					 0, binder_value);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -502,12 +545,15 @@ client_send_params(gnutls_session_t session,
 		session->key.binders[next_idx].resumption = 0;
 		session->key.binders[next_idx].idx = next_idx;
 
-		_gnutls_handshake_log("EXT[%p]: sent PSK identity '%s' (%d)\n", session, info->username, next_idx);
+		_gnutls_handshake_log("EXT[%p]: sent PSK identity '%s' (%d)\n",
+				      session, info->username, next_idx);
 
 		next_idx++;
 
 		/* Add the binder */
-		ret = _gnutls_buffer_append_data_prefix(extdata, 8, binder_value, prf_psk->output_size);
+		ret =
+		    _gnutls_buffer_append_data_prefix(extdata, 8, binder_value,
+						      prf_psk->output_size);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -516,7 +562,7 @@ client_send_params(gnutls_session_t session,
 
 	ret = 0;
 
-cleanup:
+ cleanup:
 	if (free_username)
 		_gnutls_free_datum(&username);
 
@@ -526,8 +572,7 @@ cleanup:
 	return ret;
 }
 
-static int
-server_send_params(gnutls_session_t session, gnutls_buffer_t extdata)
+static int server_send_params(gnutls_session_t session, gnutls_buffer_t extdata)
 {
 	int ret;
 
@@ -552,7 +597,7 @@ static int server_recv_params(gnutls_session_t session,
 	uint8_t binder_value[MAX_HASH_SIZE];
 	uint16_t psk_index, i;
 	gnutls_datum_t binder_recvd = { NULL, 0 };
-	gnutls_datum_t key = {NULL, 0};
+	gnutls_datum_t key = { NULL, 0 };
 	psk_ext_parser_st psk_parser;
 	psk_ext_iter_st psk_iter;
 	struct psk_st psk;
@@ -573,7 +618,7 @@ static int server_recv_params(gnutls_session_t session,
 	}
 
 	_gnutls13_psk_ext_iter_init(&psk_iter, &psk_parser);
-	for (psk_index = 0; ; psk_index++) {
+	for (psk_index = 0;; psk_index++) {
 		ret = _gnutls13_psk_ext_iter_next_identity(&psk_iter, &psk);
 		if (ret < 0) {
 			/* We couldn't find any usable PSK */
@@ -585,7 +630,8 @@ static int server_recv_params(gnutls_session_t session,
 		/* This will unpack the session ticket if it is well
 		 * formed and has the expected name */
 		if (!(session->internals.flags & GNUTLS_NO_TICKETS) &&
-		    _gnutls13_unpack_session_ticket(session, &psk.identity, &ticket_data) == 0) {
+		    _gnutls13_unpack_session_ticket(session, &psk.identity,
+						    &ticket_data) == 0) {
 			prf = ticket_data.prf;
 
 			session->internals.resumption_requested = 1;
@@ -615,12 +661,17 @@ static int server_recv_params(gnutls_session_t session,
 			break;
 		} else if (pskcred &&
 			   psk.ob_ticket_age == 0 &&
-			   psk.identity.size > 0 && psk.identity.size <= MAX_USERNAME_SIZE) {
+			   psk.identity.size > 0
+			   && psk.identity.size <= MAX_USERNAME_SIZE) {
 			prf = pskcred->binder_algo;
 
 			/* this fails only on configuration errors; as such we always
 			 * return its error code in that case */
-			ret = _gnutls_psk_pwd_find_entry(session, (char *) psk.identity.data, psk.identity.size, &key);
+			ret =
+			    _gnutls_psk_pwd_find_entry(session,
+						       (char *)psk.
+						       identity.data,
+						       psk.identity.size, &key);
 			if (ret < 0)
 				return gnutls_assert_val(ret);
 
@@ -631,7 +682,9 @@ static int server_recv_params(gnutls_session_t session,
 
 	_gnutls13_psk_ext_iter_init(&psk_iter, &psk_parser);
 	for (i = 0; i <= psk_index; i++) {
-		ret = _gnutls13_psk_ext_iter_next_binder(&psk_iter, &binder_recvd);
+		ret =
+		    _gnutls13_psk_ext_iter_next_binder(&psk_iter,
+						       &binder_recvd);
 		if (ret < 0) {
 			gnutls_assert();
 			/* We couldn't extract binder */
@@ -649,7 +702,7 @@ static int server_recv_params(gnutls_session_t session,
 	}
 
 	/* Compute the binder value for this PSK */
-	ret = compute_psk_binder(session, prf, psk_parser.binders_len+2, 0, 0,
+	ret = compute_psk_binder(session, prf, psk_parser.binders_len + 2, 0, 0,
 				 &key, &full_client_hello, resuming,
 				 binder_value);
 	if (ret < 0) {
@@ -665,7 +718,8 @@ static int server_recv_params(gnutls_session_t session,
 	}
 
 	if (session->internals.hsk_flags & HSK_PSK_KE_MODE_DHE_PSK)
-		_gnutls_handshake_log("EXT[%p]: selected DHE-PSK mode\n", session);
+		_gnutls_handshake_log("EXT[%p]: selected DHE-PSK mode\n",
+				      session);
 	else {
 		reset_cand_groups(session);
 		_gnutls_handshake_log("EXT[%p]: selected PSK mode\n", session);
@@ -674,9 +728,11 @@ static int server_recv_params(gnutls_session_t session,
 	/* save the username in psk_auth_info to make it available
 	 * using gnutls_psk_server_get_username() */
 	if (!resuming) {
-		assert(psk.identity.size < sizeof(info->username));
+		assert(psk.identity.size <= MAX_USERNAME_SIZE);
 
-		ret = _gnutls_auth_info_init(session, GNUTLS_CRD_PSK, sizeof(psk_auth_info_st), 1);
+		ret =
+		    _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
+					   sizeof(psk_auth_info_st), 1);
 		if (ret < 0) {
 			gnutls_assert();
 			goto fail;
@@ -685,8 +741,15 @@ static int server_recv_params(gnutls_session_t session,
 		info = _gnutls_get_auth_info(session, GNUTLS_CRD_PSK);
 		assert(info != NULL);
 
-		_gnutls_copy_psk_username(info, &psk.identity);
-		_gnutls_handshake_log("EXT[%p]: selected PSK identity: %s (%d)\n", session, info->username, psk_index);
+		ret = _gnutls_copy_psk_username(info, psk.identity);
+		if (ret < 0) {
+			gnutls_assert();
+			goto fail;
+		}
+
+		_gnutls_handshake_log
+		    ("EXT[%p]: selected PSK identity: %s (%d)\n", session,
+		     info->username, psk_index);
 
 		/* We currently only support early data in resuming connection,
 		 * due to lack of API function to associate encryption
@@ -696,24 +759,28 @@ static int server_recv_params(gnutls_session_t session,
 	} else {
 		if (session->internals.hsk_flags & HSK_EARLY_DATA_IN_FLIGHT) {
 			if (session->internals.anti_replay) {
-				ret = _gnutls_anti_replay_check(session->internals.anti_replay,
-								ticket_age,
-								&ticket_creation_time,
-								&binder_recvd);
+				ret =
+				    _gnutls_anti_replay_check
+				    (session->internals.anti_replay, ticket_age,
+				     &ticket_creation_time, &binder_recvd);
 				if (ret < 0) {
 					refuse_early_data = true;
-					_gnutls_handshake_log("EXT[%p]: replay detected; rejecting early data\n",
-						      session);
+					_gnutls_handshake_log
+					    ("EXT[%p]: replay detected; rejecting early data\n",
+					     session);
 				}
 			} else {
 				refuse_early_data = true;
-				_gnutls_handshake_log("EXT[%p]: anti-replay is not enabled; rejecting early data\n",
-						      session);
+				_gnutls_handshake_log
+				    ("EXT[%p]: anti-replay is not enabled; rejecting early data\n",
+				     session);
 			}
 		}
 
 		session->internals.resumed = true;
-		_gnutls_handshake_log("EXT[%p]: selected resumption PSK identity (%d)\n", session, psk_index);
+		_gnutls_handshake_log
+		    ("EXT[%p]: selected resumption PSK identity (%d)\n",
+		     session, psk_index);
 	}
 
 	session->internals.hsk_flags |= HSK_PSK_SELECTED;
@@ -788,10 +855,11 @@ static int _gnutls_psk_send_params(gnutls_session_t session,
 
 		if (session->internals.hsk_flags & HSK_PSK_KE_MODES_SENT) {
 			cred = (gnutls_psk_client_credentials_t)
-					_gnutls_get_cred(session, GNUTLS_CRD_PSK);
+			    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
 		}
 
-		if ((session->internals.flags & GNUTLS_NO_TICKETS) && !session->internals.priorities->have_psk)
+		if ((session->internals.flags & GNUTLS_NO_TICKETS)
+		    && !session->internals.priorities->have_psk)
 			return 0;
 
 		return client_send_params(session, extdata, cred);
@@ -801,7 +869,8 @@ static int _gnutls_psk_send_params(gnutls_session_t session,
 		if (!vers || !vers->tls13_sem)
 			return 0;
 
-		if ((session->internals.flags & GNUTLS_NO_TICKETS) && !session->internals.priorities->have_psk)
+		if ((session->internals.flags & GNUTLS_NO_TICKETS)
+		    && !session->internals.priorities->have_psk)
 			return 0;
 
 		if (session->internals.hsk_flags & HSK_PSK_KE_MODES_RECEIVED)
@@ -816,7 +885,8 @@ static void swap_binders(gnutls_session_t session)
 	struct binder_data_st tmp;
 
 	memcpy(&tmp, &session->key.binders[0], sizeof(struct binder_data_st));
-	memcpy(&session->key.binders[0], &session->key.binders[1], sizeof(struct binder_data_st));
+	memcpy(&session->key.binders[0], &session->key.binders[1],
+	       sizeof(struct binder_data_st));
 	memcpy(&session->key.binders[1], &tmp, sizeof(struct binder_data_st));
 }
 
@@ -841,13 +911,23 @@ static int _gnutls_psk_recv_params(gnutls_session_t session,
 		if (session->internals.hsk_flags & HSK_PSK_KE_MODES_SENT) {
 			uint16_t selected_identity = _gnutls_read_uint16(data);
 
-			for (i=0;i<sizeof(session->key.binders)/sizeof(session->key.binders[0]);i++) {
-				if (session->key.binders[i].prf != NULL && session->key.binders[i].idx == selected_identity) {
+			for (i = 0;
+			     i <
+			     sizeof(session->key.binders) /
+			     sizeof(session->key.binders[0]); i++) {
+				if (session->key.binders[i].prf != NULL
+				    && session->key.binders[i].idx ==
+				    selected_identity) {
 					if (session->key.binders[i].resumption) {
-						session->internals.resumed = true;
-						_gnutls_handshake_log("EXT[%p]: selected PSK-resumption mode\n", session);
+						session->internals.resumed =
+						    true;
+						_gnutls_handshake_log
+						    ("EXT[%p]: selected PSK-resumption mode\n",
+						     session);
 					} else {
-						_gnutls_handshake_log("EXT[%p]: selected PSK mode\n", session);
+						_gnutls_handshake_log
+						    ("EXT[%p]: selected PSK mode\n",
+						     session);
 					}
 
 					/* different PSK is selected, than the one we calculated early secrets */
@@ -855,36 +935,47 @@ static int _gnutls_psk_recv_params(gnutls_session_t session,
 						/* ensure that selected binder is set on (our) index zero */
 						swap_binders(session);
 
-						ret = _gnutls_generate_early_secrets_for_psk(session);
+						ret =
+						    _gnutls_generate_early_secrets_for_psk
+						    (session);
 						if (ret < 0)
-							return gnutls_assert_val(ret);
+							return
+							    gnutls_assert_val
+							    (ret);
 					}
-					session->internals.hsk_flags |= HSK_PSK_SELECTED;
+					session->internals.hsk_flags |=
+					    HSK_PSK_SELECTED;
 				}
 			}
 
 			return 0;
 		} else {
-			return gnutls_assert_val(GNUTLS_E_RECEIVED_ILLEGAL_EXTENSION);
+			return
+			    gnutls_assert_val
+			    (GNUTLS_E_RECEIVED_ILLEGAL_EXTENSION);
 		}
 	} else {
 		if (session->internals.hsk_flags & HSK_PSK_KE_MODES_RECEIVED) {
-			if (session->internals.hsk_flags & HSK_PSK_KE_MODE_INVALID) {
+			if (session->
+			    internals.hsk_flags & HSK_PSK_KE_MODE_INVALID) {
 				/* We received a "psk_ke_modes" extension, but with a value we don't support */
 				return 0;
 			}
 
 			pskcred = (gnutls_psk_server_credentials_t)
-					_gnutls_get_cred(session, GNUTLS_CRD_PSK);
+			    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
 
 			/* If there are no PSK credentials, this extension is not applicable,
 			 * so we return zero. */
-			if (pskcred == NULL && (session->internals.flags & GNUTLS_NO_TICKETS))
+			if (pskcred == NULL
+			    && (session->internals.flags & GNUTLS_NO_TICKETS))
 				return 0;
 
 			return server_recv_params(session, data, len, pskcred);
 		} else {
-			return gnutls_assert_val(GNUTLS_E_RECEIVED_ILLEGAL_EXTENSION);
+			return
+			    gnutls_assert_val
+			    (GNUTLS_E_RECEIVED_ILLEGAL_EXTENSION);
 		}
 	}
 }
@@ -895,7 +986,9 @@ const hello_ext_entry_st ext_mod_pre_shared_key = {
 	.gid = GNUTLS_EXTENSION_PRE_SHARED_KEY,
 	.client_parse_point = GNUTLS_EXT_TLS,
 	.server_parse_point = GNUTLS_EXT_TLS,
-	.validity = GNUTLS_EXT_FLAG_TLS | GNUTLS_EXT_FLAG_CLIENT_HELLO | GNUTLS_EXT_FLAG_TLS13_SERVER_HELLO,
+	.validity =
+	    GNUTLS_EXT_FLAG_TLS | GNUTLS_EXT_FLAG_CLIENT_HELLO |
+	    GNUTLS_EXT_FLAG_TLS13_SERVER_HELLO,
 	.send_func = _gnutls_psk_send_params,
 	.recv_func = _gnutls_psk_recv_params
 };
