@@ -179,7 +179,6 @@ CurrentAccount::updateData()
 
         // SRTP
         set_enableSRTP(accConfig.SRTP.enable, true);
-        set_rtpFallbackSRTP(accConfig.SRTP.rtpFallback, true);
         set_keyExchangeSRTP(accConfig.SRTP.keyExchange, true);
 
         // TURN
@@ -222,6 +221,9 @@ CurrentAccount::updateData()
         set_autoTransferSizeThreshold(settingsManager_->getValue(Settings::Key::AcceptTransferBelow)
                                           .toInt(),
                                       true);
+
+        // UI Customization settings
+        set_uiCustomization(accConfig.uiCustomization, true);
     } catch (...) {
         qWarning() << "Can't update current account info data for" << id_;
     }
