@@ -135,10 +135,19 @@ MainApplication::init()
     settingsManager_ = new AppSettingsManager(this);
     systemTray_ = new SystemTray(settingsManager_, this);
 
+    // These should should be QueuedConnection to ensure that the
+    // they are executed after the QML engine has been initialized,
+    // and after the QSystemTrayIcon has been created and shown.
     QObject::connect(settingsManager_,
                      &AppSettingsManager::retranslate,
                      engine_.get(),
-                     &QQmlApplicationEngine::retranslate);
+                     &QQmlApplicationEngine::retranslate,
+                     Qt::QueuedConnection);
+    QObject::connect(settingsManager_,
+                     &AppSettingsManager::retranslate,
+                     this,
+                     &MainApplication::initSystray,
+                     Qt::QueuedConnection);
 
     setWindowIcon(QIcon(":/images/jami.ico"));
 
@@ -197,12 +206,6 @@ MainApplication::init()
     engine_.get()->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(false));
 #endif
 
-#ifdef APPSTORE
-    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(true));
-#else
-    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(false));
-#endif
-
     initQmlLayer();
 
     settingsManager_->setValue(Settings::Key::StartMinimized,
@@ -368,7 +371,13 @@ MainApplication::initSystray()
 {
     systemTray_->setIcon(QIcon(":/images/jami.svg"));
 
-    QMenu* systrayMenu = new QMenu();
+    QMenu* menu {nullptr};
+    // If there was a previous menu, reuse it, otherwise create a new one.
+    if ((menu = systemTray_->contextMenu())) {
+        menu->clear();
+    } else {
+        menu = new QMenu;
+    }
 
     QString quitString;
 #ifdef Q_OS_WINDOWS
@@ -400,9 +409,10 @@ MainApplication::initSystray()
                 }
             });
 
-    systrayMenu->addAction(restoreAction);
-    systrayMenu->addAction(quitAction);
-    systemTray_->setContextMenu(systrayMenu);
+    menu->addAction(restoreAction);
+    menu->addAction(quitAction);
+    systemTray_->setContextMenu(menu);
+
     systemTray_->show();
 }
 
