@@ -72,11 +72,11 @@ public:
                   const QString& fileId,
                   const QString& filePath = {});
 
-    void copyTo(const QString& accountId,
-                const QString& convId,
-                const QString& interactionId,
-                const QString& destPath,
-                const QString& displayName);
+    QString copyTo(const QString& accountId,
+                   const QString& convId,
+                   const QString& interactionId,
+                   const QString& destPath,
+                   const QString& displayName);
 
     void cancel(const QString& accountId, const QString& conversationId, const QString& fileId);
 
